pub fn init()Expand description
Initializes the logging system without a listener.
Note that the init! macro is the preferred method to do this in the public API.
use breadcrumbs::init;
init();pub fn init()Initializes the logging system without a listener.
Note that the init! macro is the preferred method to do this in the public API.
use breadcrumbs::init;
init();